import React, { Component } from "react"
import { IgrLiveGridModule } from "igniteui-react-grids/ES5/igr-live-grid-module";
import { IgrTextColumnModule } from "igniteui-react-grids/ES5/igr-text-column-module";
import { IgrNumericColumnModule } from "igniteui-react-grids/ES5/igr-numeric-column-module";

import { IgrLiveGrid } from "igniteui-react-grids/ES5/igr-live-grid";
import { IgrNumericColumn } from "igniteui-react-grids/ES5/igr-numeric-column";
import { IgrTextColumn } from "igniteui-react-grids/ES5/igr-text-column";

import { IgrTemplateHeader } from "igniteui-react-grids/ES5/igr-template-header";
import { TemplateHeaderCellUpdatingEventArgs } from "igniteui-react-grids/ES5/igr-template-header-cell-updating-event-args";
import { TemplateCellInfo } from "igniteui-react-grids/ES5/igr-template-cell-info";

IgrTextColumnModule.register();
IgrNumericColumnModule.register();
IgrLiveGridModule.register();

export default class HeaderGrid extends React.Component<any, any> {

    public data: any[];

    constructor(props: any) {
        super(props);

        this.onGridRef = this.onGridRef.bind(this);

        this.data = [{
            Discontinued: false,
            OrderDate: new Date("2012-02-12"),
            ProductID: 1,
            ProductName: "Chai",
            QuantityPerUnit: "10 boxes x 20 bags",
            ReorderLevel: 10,
            UnitPrice: 18.0000,
            UnitsInStock: 39
        }, {
            Discontinued: false,
            OrderDate: new Date("2003-03-17"),
            ProductID: 2,
            ProductName: "Chang",
            QuantityPerUnit: "24 - 12 oz bottles",
            ReorderLevel: 25,
            UnitPrice: 19.0000,
            UnitsInStock: 17
        }, {
            Discontinued: false,
            OrderDate: new Date("2006-03-17"),
            ProductID: 3,
            ProductName: "Aniseed Syrup",
            QuantityPerUnit: "12 - 550 ml bottles",
            ReorderLevel: 25,
            UnitPrice: 10.0000,
            UnitsInStock: 13
        }, {
            Discontinued: false,
            OrderDate: new Date("2016-03-17"),
            ProductID: 4,
            ProductName: "Chef Antons Cajun Seasoning",
            QuantityPerUnit: "48 - 6 oz jars",
            ReorderLevel: 0,
            UnitPrice: 22.0000,
            UnitsInStock: 53
        }, {
            Discontinued: true,
            OrderDate: new Date("2011-11-11"),
            ProductID: 5,
            ProductName: "Chef Antons Gumbo Mix",
            QuantityPerUnit: "36 boxes",
            ReorderLevel: 0,
            UnitPrice: 21.3500,
            UnitsInStock: 0
        }];
    }

    public render() {
        return (
            <div>
                <IgrLiveGrid
                    ref={this.onGridRef}
                    height="100%"
                    width="100%"
                    dataSource={this.data}
                    autoGenerateColumns={false} >
                    <IgrTextColumn propertyPath="ProductName" headerText="Product Name" />
                    <IgrTextColumn propertyPath="QuantityPerUnit" headerText="Quantity Per Unit" />
                    <IgrNumericColumn propertyPath="ProductID" headerText="Product ID" />
                    {/* <IgrNumericColumn propertyPath="UnitsInStock" headerText="Units In Stock" /> */}
                </IgrLiveGrid>
            </div>
        )
    }

    public onGridRef(grid: IgrLiveGrid) {
        if (grid != null) {            
            const col = new IgrNumericColumn({});
            col.propertyPath = "UnitsInStock";
        
            const header: IgrTemplateHeader = new IgrTemplateHeader({});
            header.cellUpdating = this.headerCellUpdating;

            col.header = header;

            grid.columns.add(col);
        }
    }

    public headerCellUpdating(sender: IgrTemplateHeader, e: TemplateHeaderCellUpdatingEventArgs) {
        const content = e.content as HTMLDivElement;
        let span1: HTMLSpanElement | null = null;        
        let button1 : HTMLButtonElement | null = null;
        const info = e.cellInfo as TemplateCellInfo;
        const item = info.rowItem;

        if (content.childElementCount === 0) {

            span1 = document.createElement("span");            
            button1 = document.createElement("button");

            content.style.verticalAlign = "top";
            content.style.marginTop = "15px";
            content.style.lineHeight = "normal";
            content.style.display = "inline-grid";
            content.style.fontFamily = "Verdana";
            content.style.fontSize = "13px";

            content.appendChild(span1);            
            content.appendChild(button1);
        }
        else {
            span1 = content.children[0] as HTMLSpanElement;            
            button1 = content.children[1] as HTMLButtonElement;
        }

        if (span1 && button1) {
            span1.textContent = "Units In Stock!";
            button1.textContent = "PIN";
        }
    }

    public initData() {

    }
}